@@ -7,6 +7,9 @@ module.exports = {
   },
 
   rules: {
+    'indent': ['warn', 2, { "SwitchCase": 1 }],
+    "space-infix-ops": ["warn", { "int32Hint": false }],
+
     "no-cond-assign": ["off"],
     "no-useless-escape": ["off"],
     "no-empty": ["off"],
